
"""Buttons2  shows how to construct a customized 
   event-handling function for each button in a GUI 
   by using a function that returns functions as answers.
"""
from Tkinter import *

HOW_MANY = 8  # how many buttons we place into the GUI
all_counts = HOW_MANY * [0]  # the data structure

# The function that contructs event handlers:

def constructHandler(but, location) :
    """constructs a custom event-handling function.

       parameters:  
          but - a button object, 
              the button just constructed
              that requires an event-handling function
          location - the position of the button on the GUI
    """
    def handlePress() :
        """is called when the button,  but,  is pressed: 
           it updates the  all_counts  data structure and
           updates  but's  text
        """
        all_counts[location] = all_counts[location]+1
        but.configure(text=all_counts[location])

    return handlePress 


myfont = ("Arial", 16, "bold")
window = Tk()
window.title("counters")

width = HOW_MANY * 100
window.geometry(str(width) + "x120")

frame = Frame(window)
frame.grid()


# construct all the buttons with a loop:

for i in range(HOW_MANY) :  

    new_button = Button(frame, font = myfont, text = 0,
                    fg = "blue", bg = "white", width = 4, height = 2)
    new_button.grid(row = 1, column = i, padx = 10, pady = 10 )

    new_handler = constructHandler(new_button,i)
    # connect the  new_handler  function to the new button:
    new_button.configure(command = new_handler)

window.mainloop()
