
"""Counters3  shows how to remember the addresses of all 
   the button objects so that the press of one button 
   can affect all the others.
"""

from Tkinter import *

HOW_MANY = 8      # how many buttons we place into the GUI

all_counts = HOW_MANY * [0]  # the data structure
all_buttons = [] # remembers addresses of all button objects

def constructHandler(but, location) :
    """constructs a custom event-handling function for a GUI button.
       parameters: but - a button object, the button just constructed 
                   location - the position of the button 
    """
    def handlePress() :
        """is called when  but  is pressed: it increases 
           the count for  but  and updates its text.
           It also _erases_ the text of all other buttons.
        """
        # update the count with one more press:
        all_counts[location] = all_counts[location] + 1

        # erase text of all the buttons with a loop:
        for b in all_buttons :
            b.configure(text = " ")

        # display the new count of  but :
        but.configure(text = all_counts[location])  

    return handlePress  


####THE VIEW (GUI) PART STARTS HERE:

myfont = ("Arial", 16, "bold")
window = Tk()
window.title("counters")

width = HOW_MANY * 100
window.geometry(str(width) + "x120")

frame = Frame(window)
frame.grid()

# RECALL THAT  all_buttons  will collect the addresses 
#   of all the button objects....

for i in range(HOW_MANY) :

    new_button = Button(frame, font = myfont, text = 0,
                    fg = "blue", bg = "white", width = 4, height = 2)
    new_button.grid(row = 1, column = i, padx = 10, pady = 10 )

    new_handler = constructHandler(new_button,i)
    new_button.configure(command = new_handler)

    all_buttons = all_buttons + [new_button] 
                               # remember the new button!
window.mainloop()


